@@ -4,7 +4,7 @@ from unit_parse.config import Quantity, config
 from unit_parse.pre_processing_substitution import remove_strings, substitution
 from unit_parse.pre_processing_multiple import multiple_quantities_main
 from unit_parse.core import text_list_to_quantity
-from unit_parse.post_processing import remove_duplicates
+from unit_parse.reduce_quantities import reduce_quantities
 from unit_parse.utils import remove_empty_cells
 from unit_parse.logger import logger
 
@@ -38,15 +38,15 @@ def parser(text_in: str) -> Union[Quantity, list[Quantity], list[list[Quantity]]
     out = text_list_to_quantity(text_list)
 
     # post-processing
-    out = remove_duplicates(out)
     out = remove_empty_cells(out)
+    out = reduce_quantities(out)
 
     # return unit instead of list if just one
-    if isinstance(out, list) and len(out) == 1:
-        if not isinstance(out[0], list):
-            out = out[0]
-        elif isinstance(out[0], list) and len(out[0]) == 1:
-            out = out[0][0]
+    # if isinstance(out, list) and len(out) == 1:
+    #     if not isinstance(out[0], list):
+    #         out = out[0]
+    #     elif isinstance(out[0], list) and len(out[0]) == 1:
+    #         out = out[0][0]
 
     logger.info(f"OUTPUT: {out}'")
     return out
